import scipy.io

def load_emg_data(file_path):
    """
    Laadt EMG-gegevens uit een .mat bestand en retourneert de kanaalnamen.
    """
    try:
        mat_data = scipy.io.loadmat(file_path)
        emg_data = mat_data.get('emg_data_walking')
        
        if emg_data is None:
            raise KeyError("De verwachte variabele 'emg_data_walking' is niet in het bestand aanwezig.")
        
        channel_names = [ch[0] for ch in emg_data['data_headers'][0][0][0]]
        
        print("EMG-kanalen:")
        for idx, name in enumerate(channel_names):
            print(f"{idx}: {name}")
        
        return channel_names
    except Exception as e:
        print(f"Fout bij het laden van het EMG-bestand: {e}")
        return []

file_path = "emg_data_walking.mat"
channel_names = load_emg_data(file_path)

# Gekozen spieren met validatie
chosen_muscles = {
    'rectus_femoris': 0,
    'tibialis_anterior': 7
}

valid_muscles = {name: idx for name, idx in chosen_muscles.items() if idx < len(channel_names)}
print(f"Gekozen spieren: {valid_muscles}")
